@@ -161,8 +161,8 @@ def connect(addr, timeout=None, deserialize=True, connection_args=None):
     retried until the *timeout* is expired.
     """
     if timeout is None:
-        timeout = config.get('connect-timeout', 3)
-        timeout = float(parse_timedelta(timeout, default='seconds'))
+        timeout = config.get('connect-timeout', '3s')
+    timeout = parse_timedelta(timeout, default='seconds')
 
     scheme, loc = parse_address(addr)
     backend = registry.get_backend(scheme)
